@@ -736,7 +736,8 @@ class Image(Vectorizable, Landmarkable, Viewable):
             Default: 'ceil'
         kwargs : dict
             Passed through to the interpolator. See `menpo.interpolation`
-            for details.
+            for details. Note that mode is set to nearest to avoid numerical
+            issues, and cannot be changed here by the user.
 
         Returns
         -------
@@ -783,6 +784,11 @@ class Image(Vectorizable, Landmarkable, Viewable):
         # (note that max_index = length - 1, as 0 based)
         scale_factors = (scale * shape - 1) / (shape - 1)
         inverse_transform = NonUniformScale(scale_factors).pseudoinverse
+        # for rescaling we enforce that mode is nearest to avoid num. errors
+        if 'mode' in kwargs:
+            raise ValueError("Cannot set 'mode' kwarg on rescale - set to "
+                             "'nearest' to avoid numerical errors")
+        kwargs['mode'] = 'nearest'
         # Note here we pass warp_mask to warp_to. In the case of
         # Images that aren't MaskedImages this kwarg will
         # harmlessly fall through so we are fine.
